﻿using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _9399
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.Meter;

            Proj4Projection proj4 = new Proj4Projection(4326, 3857);
            proj4.Open();

            RotationProjection projection = new RotationProjection(45);
            projection.PivotCenter = map.CurrentExtent.GetCenterPoint();
            projection.Open();


            LayerOverlay layerOverlay = new LayerOverlay();

            MrSidRasterLayer mrSidRasterLayer = new MrSidRasterLayer("../../AppData/World.sid", "../../AppData/World.sdw");
            mrSidRasterLayer.ImageSource.Projection = projection;
            mrSidRasterLayer.Open();
            layerOverlay.Layers.Add(mrSidRasterLayer);


            PrinterInteractiveOverlay printerOverlay = new PrinterInteractiveOverlay();

            PagePrinterLayer pagePrinterLayer = new PagePrinterLayer(PrinterPageSize.AnsiA, PrinterOrientation.Landscape);
            pagePrinterLayer.Open();

            MapPrinterLayer mapPrinterLayer = new MapPrinterLayer();
            mapPrinterLayer.MapUnit = GeographyUnit.DecimalDegree;
            mapPrinterLayer.MapExtent = mrSidRasterLayer.GetBoundingBox();
            mapPrinterLayer.BackgroundMask = new AreaStyle(new GeoPen(GeoColor.StandardColors.Black, 1));
            mapPrinterLayer.Open();

            RectangleShape pageBoundingbox = pagePrinterLayer.GetPosition(PrintingUnit.Inch);
            mapPrinterLayer.SetPosition(7, 8, pageBoundingbox.GetCenterPoint().X, pageBoundingbox.GetCenterPoint().Y, PrintingUnit.Inch);

            ZoomLevelSet zoomLevelSet = new ZoomLevelSet();
            mapPrinterLayer.MapExtent = ExtentHelper.ZoomToScale(zoomLevelSet.ZoomLevel01.Scale, mrSidRasterLayer.GetBoundingBox(), mapPrinterLayer.MapUnit, (float)mapPrinterLayer.GetBoundingBox().Width, (float)mapPrinterLayer.GetBoundingBox().Height);

            mapPrinterLayer.Layers.Add(mrSidRasterLayer);


            printerOverlay.PrinterLayers.Add(pagePrinterLayer);
            printerOverlay.PrinterLayers.Add(mapPrinterLayer);

            map.InteractiveOverlays.Add(printerOverlay);


            map.CurrentExtent = pagePrinterLayer.GetBoundingBox();

            map.Refresh();
        }
    }
}
